/* wecrd.h
 *  This header provides the function declarations, constants, 
 *  and error codes for Winford Engineering's Portal API.
 *
 *  Winford Engineering
 *  www.winfordeng.com
 */

#ifndef WECRD_H
#define WECRD_H

#ifdef __cplusplus
#define PREFUNCTION extern "C"
#else
#define PREFUNCTION extern
#endif

// On Windows platforms, specify that all these functions should
// be called using the Standard Call calling convention.
#ifdef WIN32
#define MIDFUNCTION __stdcall
#else
// Otherwise, define MIDFUNCTION as being nothing
#define MIDFUNCTION 
#endif

/*Function declarations*/
PREFUNCTION long MIDFUNCTION we_OpenCard(long Model, long BaseAddr);
PREFUNCTION long MIDFUNCTION we_ConfigureCard(long Handle, long Port, long Mode);
PREFUNCTION long MIDFUNCTION we_OutputValue(long Handle, long Port, long Value);
PREFUNCTION long MIDFUNCTION we_InputValue(long Handle, long Port, long* Value);
PREFUNCTION long MIDFUNCTION we_CloseCard(long Handle);
PREFUNCTION long MIDFUNCTION we_CloseAllCards(long Reserved);
PREFUNCTION long MIDFUNCTION we_ReadBack(long Handle, long Port, long* Value);

/*Card Model constants*/
#define WECRD_155B 10 

/*Various Constants*/
#define WECRD_INPUT		1 //port in input state 
#define WECRD_OUTPUT	2 //port in output state 

/*Error Codes*/

#define WECRD_SUCCESS				0
#define WECRD_GENERAL_ERROR			-1
#define WECRD_IO_ERROR				-10  //unable to read or write a port. In Linux, this may result from improper permissions on /dev/port

#define WECRD_INVALID_HANDLE		-101 //No card is currently open with that handle
#define WECRD_INVALID_MODEL			-102 //Model was invalid (doesn't exist)
#define WECRD_INVALID_ADDRESS		-103 //Address invalid for the specified model
#define WECRD_INVALID_PORT			-104 //Port specified is invalid for the card model
#define WECRD_INVALID_PORTMODE		-105 //There is no such mode for that port, or that mode is currently unavailable
#define WECRD_INVALID_PORTVALUE		-106 //Value passed is out of valid range
#define WECRD_ADDRESS_CONFLICT		-114 //Desired address conflicts with an opened card (Card may have been previously opened and never closed)
#define WECRD_CARD_NOTFOUND			-115 //Card doesn't seem to exist at that address
#define WECRD_WRONG_PORTMODE		-150 //Card is not in the correct mode.
						 //(such as calling OutputValue when the port is in input mode)

#endif WECRD_H

